@@ -144,7 +144,7 @@ int main(int argc, char *argv[])
 	char one_shot = 0;
 	char no_heading = 0;
 	int bytes_limit = 0;
-	time_t last_changed = (time_t)-1;
+	time_t last_changed = (time_t)0;
 	char continue_on_error = 0, dummy;
 	int show_n = -1;
 	long int max_age = -1;
